@@ -6,15 +6,15 @@
   toset <- !(names(op.dplyr) %in% names(op))
   if (any(toset)) options(op.dplyr[toset])
 
-  local(envir = ns_env("dplyr"), {
-    delayedAssign("env_bind_active", {
-      if (utils::packageVersion("rlang") < "0.2.99") {
-        env_get(ns_env("rlang"), "env_bind_fns")
-      } else {
-        env_get(ns_env("rlang"), "env_bind_active")
-      }
-    })
-  })
+  .Call(dplyr_init_library, ns_env("dplyr"), ns_env("vctrs"), ns_env("rlang"))
+
+  has_dbplyr <- is_installed("dbplyr")
+  if (!has_dbplyr || !exists("count.tbl_sql", ns_env("dbplyr"))) {
+    s3_register("dplyr::count", "tbl_sql")
+    s3_register("dplyr::tally", "tbl_sql")
+  }
+
+  run_on_load()
 
   invisible()
 }
@@ -34,13 +34,3 @@
 .onDetach <- function(libpath) {
   setHook(packageEvent("plyr", "attach"), NULL, "replace")
 }
-
-when_attached <- function(pkg, action) {
-  if (is_attached(pkg)) {
-    action
-  } else {
-    setHook(packageEvent(pkg, "attach"), function(...) action)
-  }
-}
-
-is_attached <- function(pkg) paste0("package:", pkg) %in% search()
