@@ -5,13 +5,11 @@ namespace dplyr {
 void stop_summarise_unsupported_type(SEXP result) {
   DPLYR_ERROR_INIT(1);
     DPLYR_ERROR_SET(0, "result", result);
-  DPLYR_ERROR_MESG_INIT(0);
   DPLYR_ERROR_THROW("dplyr:::summarise_unsupported_type");
 }
 
 void stop_summarise_mixed_null() {
   DPLYR_ERROR_INIT(0);
-  DPLYR_ERROR_MESG_INIT(0);
   DPLYR_ERROR_THROW("dplyr:::summarise_mixed_null");
 }
 
@@ -21,7 +19,6 @@ void stop_summarise_incompatible_size(int index_group, int index_expression, int
     DPLYR_ERROR_SET(1, "index", Rf_ScalarInteger(index_expression + 1));
     DPLYR_ERROR_SET(2, "expected_size", Rf_ScalarInteger(expected_size));
     DPLYR_ERROR_SET(3, "size", Rf_ScalarInteger(size));
-  DPLYR_ERROR_MESG_INIT(0);
   DPLYR_ERROR_THROW("dplyr:::summarise_incompatible_size");
 }
 
@@ -63,13 +60,14 @@ bool is_useful_chunk(SEXP ptype) {
   return !Rf_inherits(ptype, "data.frame") || XLENGTH(ptype) > 0;
 }
 
-SEXP dplyr_summarise_recycle_chunks(SEXP chunks, SEXP rows, SEXP ptypes) {
+SEXP dplyr_summarise_recycle_chunks(SEXP chunks, SEXP rows, SEXP ptypes, SEXP results) {
   R_len_t n_chunks = LENGTH(chunks);
   R_len_t n_groups = LENGTH(rows);
 
-  SEXP res = PROTECT(Rf_allocVector(VECSXP, 2));
+  SEXP res = PROTECT(Rf_allocVector(VECSXP, 3));
   Rf_namesgets(res, dplyr::vectors::names_summarise_recycle_chunks);
   SET_VECTOR_ELT(res, 0, chunks);
+  SET_VECTOR_ELT(res, 2, results);
 
   SEXP useful = PROTECT(Rf_allocVector(LGLSXP, n_chunks));
   int* p_useful = LOGICAL(useful);
@@ -130,10 +128,21 @@ SEXP dplyr_summarise_recycle_chunks(SEXP chunks, SEXP rows, SEXP ptypes) {
 
       SEXP chunks_j = p_chunks[j];
       int* p_sizes = INTEGER(sizes);
+      bool reset_result_j = false;
       for (int i = 0; i < n_groups; i++, ++p_sizes) {
-        SET_VECTOR_ELT(chunks_j, i,
-          vctrs::short_vec_recycle(VECTOR_ELT(chunks_j, i), *p_sizes)
-        );
+        SEXP chunks_j_i = VECTOR_ELT(chunks_j, i);
+        if (*p_sizes != vctrs::short_vec_size(chunks_j_i)) {
+          reset_result_j = true;
+          SET_VECTOR_ELT(chunks_j, i,
+            vctrs::short_vec_recycle(chunks_j_i, *p_sizes)
+          );
+        }
+      }
+
+      // results[[j]] will be regenerated from !!!chunks[[j]]
+      // as it's been recycled
+      if (reset_result_j) {
+        SET_VECTOR_ELT(results, j, R_NilValue);
       }
     }
     SET_VECTOR_ELT(res, 0, chunks);
