@@ -1,5 +1,3 @@
-context("funs-predicates")
-
 test_that("all_exprs() creates intersection", {
   expect_identical(all_exprs(am == 1), quo(am == 1))
 
@@ -13,11 +11,3 @@ test_that("any_exprs() creates union", {
   quo <- set_env(quo((!!quo(cyl == 2)) | (!!quo(am == 1))), base_env())
   expect_identical(any_exprs(cyl == 2, am == 1), quo)
 })
-
-test_that("all_exprs() without expression returns an error", {
-  expect_error(
-    all_exprs(),
-    "At least one expression must be given",
-    fixed = TRUE
-  )
-})
