@@ -1,5 +1,3 @@
-context("if_else")
-
 test_that("scalar true and false are vectorised", {
   x <- c(TRUE, TRUE, FALSE, FALSE)
   expect_equal(if_else(x, 1, 2), c(1, 1, 2, 2))
@@ -28,15 +26,15 @@ test_that("works with lists", {
 # Errors ------------------------------------------------------------------
 
 test_that("if_else() give meaningful errors", {
-  verify_output(test_path("test-if-else-errors.txt"), {
-
-    if_else(1:10, 1, 2)
-    if_else(1:3 < 2, 1:2, 1:3)
-    if_else(1:3 < 2, 1:3, 1:2)
-    if_else(1:3 < 2, 1, 1L)
+  expect_snapshot({
+    (expect_error(if_else(1:10, 1, 2)))
+    (expect_error(if_else(1:3 < 2, 1:2, 1:3)))
+    (expect_error(if_else(1:3 < 2, 1:3, 1:2)))
+    (expect_error(if_else(1:3 < 2, 1, 1L)))
 
     x <- factor("x")
     y <- ordered("x")
-    if_else(1:3 < 2, x, y)
+    (expect_error(if_else(1:3 < 2, x, y)))
   })
+
 })
