@@ -1,21 +1,33 @@
-context("Select")
+test_that("select preserves grouping", {
+  gf <- group_by(tibble(g = 1:3, x = 3:1), g)
 
-test_that("select does not lose grouping (#147)", {
-  df <- tibble(a = rep(1:4, 2), b = rep(1:4, each = 2), x = runif(8))
-  grouped <- df %>% group_by(a) %>% select(a, b, x)
-
-  expect_groups(grouped, "a")
+  i <- count_regroups(out <- select(gf, h = g))
+  expect_equal(i, 0)
+  expect_equal(group_vars(out), "h")
 })
 
-test_that("grouping variables preserved with a message (#1511)", {
+test_that("grouping variables preserved with a message, unless already selected (#1511, #5841)", {
   df <- tibble(g = 1:3, x = 3:1) %>% group_by(g)
 
-  expect_message(res <- select(df, x), "Adding missing grouping variables")
+  expect_snapshot({
+    res <- select(df, x)
+  })
   expect_named(res, c("g", "x"))
+
+  df <- tibble(a = 1, b = 2, c = 3) %>% group_by(a)
+  expect_equal(df %>% select(a = b), tibble(a = 2))
+
+  df <- tibble(a = 1, b = 2, c = 3) %>% group_by(a, b)
+  expect_snapshot({
+    expect_equal(df %>% select(a = c), tibble(b = 2, a = 3) %>% group_by(b))
+    expect_equal(df %>% select(b = c), tibble(a = 1, b = 3) %>% group_by(a))
+  })
 })
 
 test_that("non-syntactic grouping variable is preserved (#1138)", {
-  df <- tibble(`a b` = 1L) %>% group_by(`a b`) %>% select()
+  expect_snapshot(
+    df <- tibble(`a b` = 1L) %>% group_by(`a b`) %>% select()
+  )
   expect_named(df, "a b")
 })
 
@@ -30,12 +42,16 @@ test_that("select doesn't fail if some names missing", {
 })
 
 
-# Empty selects -------------------------------------------------
+# Special cases -------------------------------------------------
 
 test_that("select with no args returns nothing", {
   empty <- select(mtcars)
   expect_equal(ncol(empty), 0)
   expect_equal(nrow(empty), 32)
+
+  empty <- select(mtcars, !!!list())
+  expect_equal(ncol(empty), 0)
+  expect_equal(nrow(empty), 32)
 })
 
 test_that("select excluding all vars returns nothing", {
@@ -49,6 +65,16 @@ test_that("negating empty match returns everything", {
   expect_equal(select(df, -starts_with("xyz")), df)
 })
 
+test_that("can select with duplicate columns", {
+  df <- tibble(x = 1, x = 2, y = 1, .name_repair = "minimal")
+
+  # can extract duplicate cols by position
+  expect_named(df %>% select(1, 3), c("x", "y"))
+
+  # can select out non-duplicated columns
+  expect_named(df %>% select(y), "y")
+})
+
 # Select variables -----------------------------------------------
 
 test_that("select can be before group_by (#309)", {
@@ -64,22 +90,6 @@ test_that("select can be before group_by (#309)", {
   expect_equal(names(dfagg), c("id", "year", "var1"))
 })
 
-test_that("rename errors with invalid grouped data frame (#640)", {
-  df <- tibble(a = 1:3, b = 2:4, d = 3:5) %>% group_by(a, b)
-  df$a <- NULL
-  expect_error(
-    df %>% rename(e = d),
-    "not found in groups metadata"
-  )
-  expect_error(
-    df %>% rename(e = b),
-    "not found in groups metadata"
-  )
-})
-
-test_that("rename() handles data pronoun", {
-  expect_identical(rename(tibble(x = 1), y = .data$x), tibble(y = 1))
-})
 
 test_that("select succeeds in presence of raw columns (#1803)", {
   df <- tibble(a = 1:3, b = as.raw(1:3))
@@ -98,14 +108,6 @@ test_that("arguments to select() don't match vars_select() arguments", {
   expect_identical(select(group_by(df, a), include = a), group_by(tibble(include = 1), include))
 })
 
-test_that("arguments to rename() don't match vars_rename() arguments (#2861)", {
-  df <- tibble(a = 1)
-  expect_identical(rename(df, var = a), tibble(var = 1))
-  expect_identical(rename(group_by(df, a), var = a), group_by(tibble(var = 1), var))
-  expect_identical(rename(df, strict = a), tibble(strict = 1))
-  expect_identical(rename(group_by(df, a), strict = a), group_by(tibble(strict = 1), strict))
-})
-
 test_that("can select() with .data pronoun (#2715)", {
   expect_identical(select(mtcars, .data$cyl), select(mtcars, cyl))
 })
@@ -114,25 +116,15 @@ test_that("can select() with character vectors", {
   expect_identical(select(mtcars, "cyl", !!"disp", c("cyl", "am", "drat")), mtcars[c("cyl", "disp", "am", "drat")])
 })
 
-test_that("rename() to UTF-8 column names", {
-  skip_on_os("windows") # needs an rlang update? #3049
-  df <- tibble(a = 1) %>% rename("\u5e78" := a)
-
-  expect_equal(colnames(df), "\u5e78")
-})
-
 test_that("select() treats NULL inputs as empty", {
   expect_identical(select(mtcars, cyl), select(mtcars, NULL, cyl, NULL))
 })
 
-test_that("can select() or rename() with strings and character vectors", {
+test_that("can select() with strings and character vectors", {
   vars <- c(foo = "cyl", bar = "am")
 
   expect_identical(select(mtcars, !!!vars), select(mtcars, foo = cyl, bar = am))
   expect_identical(select(mtcars, !!vars), select(mtcars, foo = cyl, bar = am))
-
-  expect_identical(rename(mtcars, !!!vars), rename(mtcars, foo = cyl, bar = am))
-  expect_identical(rename(mtcars, !!vars), rename(mtcars, foo = cyl, bar = am))
 })
 
 test_that("select works on empty names (#3601)", {
@@ -145,7 +137,6 @@ test_that("select works on empty names (#3601)", {
 })
 
 test_that("select works on NA names (#3601)", {
-  skip("to be discussed")
   df <- data.frame(x=1, y=2, z=3)
   colnames(df) <- c("x","y",NA)
   expect_identical(select(df, x)$x, 1)
@@ -153,3 +144,58 @@ test_that("select works on NA names (#3601)", {
   colnames(df) <- c(NA,"y","z")
   expect_identical(select(df, y)$y, 2)
 })
+
+test_that("select() keeps attributes of raw data frames (#5831)", {
+  df <- data.frame(x = 1)
+  attr(df, "a") <- "b"
+  expect_equal(attr(select(df, x), "a"), "b")
+})
+
+test_that("select() provides informative errors", {
+  expect_snapshot({
+    (expect_error(select(mtcars, 1 + "")))
+  })
+})
+
+
+# dplyr_col_select() ------------------------------------------------------
+
+test_that("dplyr_col_select() aborts when `[` implementation is broken", {
+  local_methods(
+    "[.dplyr_test_broken_operator" = function(x, ...) {
+      unclass(x)
+    },
+    "[.dplyr_test_operator_wrong_size" = function(x, ...) {
+      data.frame()
+    }
+  )
+  df1 <- new_tibble(list(x = 1), nrow = 1L, class = "dplyr_test_broken_operator")
+  expect_snapshot({
+    (expect_error(
+      select(df1, 1:2)
+    ))
+    (expect_error(
+      select(df1, 0)
+    ))
+  })
+  df2 <- new_tibble(list(x = 1), nrow = 1L, class = "dplyr_test_operator_wrong_size")
+  expect_error(select(df2, 1:2))
+
+  expect_snapshot({
+    # from vctrs
+    (expect_error(
+      select(df1, 2)
+    ))
+
+    # not returning a data frame
+    (expect_error(
+      select(df1, 1)
+    ))
+
+    # unexpected number of columns
+    (expect_error(
+      select(df2, 1)
+    ))
+  })
+
+})
